Crate defillama_rs

Crate defillama_rs 

A Rust client for the DefiLlama API

This crate provides an interface to interact with DefiLlama’s API, allowing users to fetch data such as token prices, TVL, and more.

Re-exports

pub use client::DefiLlamaClient;
pub use error::DefillamaError;

Modules

client
Client implementation for the DefiLlama API
error
Error types for the DefiLlama API client
models
Data models for the DefiLlama API responses