A Rust client for the DefiLlama API
This crate provides an interface to interact with DefiLlama’s API, allowing users to fetch data such as token prices, TVL, and more.
Re-exports
pub use client::DefiLlamaClient;pub use error::DefillamaError;